require 'httparty'
require 'json'
require './lib/roadmap'

class MyRecords
  include HTTParty
  include Roadmap

  def initialize(email, password)
    @base_url = 'https://www.bloc.io/api/v1'
    response = self.class.post(@base_url + '/sessions', body:
    {"email": email, "password": password})
    raise "Invalid credentials." if response.code != 200
    @auth_token = response["auth_token"]
  end

  def get_me
    response = self.class.get(@base_url + '/users/me', headers:
    { "authorization" => @auth_token })
    data = JSON.parse(response.body)
    data
  end

  def get_mentor_availability(mentor_id)
    id = mentor_id.to_s
    response = self.class.get(@base_url + '/mentors/' + id +
    '/student_availability', headers: { "authorization" => @auth_token })
    slots = JSON.parse(response.body)
    slots
  end

  def get_messages(page = nil)
    page.nil? ? page = '' : page = page.to_s
    response = self.class.get(@base_url + '/message_threads' + page,
    headers: { "authorization" => @auth_token })
    messages = JSON.parse(response.body)
    messages
  end

  def create_message(sender, recipient_id, token = nil, subject = nil, stripped_text)
    response = self.class.post(@base_url + '/messages', body:
    {"sender": sender, "recipient_id": recipient_id, "token": token,
    "subject": subject, "stripped-text": stripped_text}, headers:
    { "authorization" => @auth_token})
    response
  end

  def create_submission(assignment_branch, assignment_commit_link, checkpoint_id, comment, enrollment_id)
    response = self.class.post(@base_url + '/checkpoint_submissions', body:
    {"assignment_branch": assignment_branch, "assignment_commit_link": assignment_commit_link,
     "checkpoint_id": checkpoint_id, "comment": comment, "enrollment_id": enrollment_id}, headers:
     { "authorization" => @auth_token })
    response
  end

  def update_submission(id, assignment_branch, assignment_commit_link, checkpoint_id, comment, enrollment_id)
    response = self.class.put(@base_url + '/checkpoint_submissions/' + id, body:
    {"id": id, "assignment_branch": assignment_branch, "assignment_commit_link": assignment_commit_link,
     "checkpoint_id": checkpoint_id, "comment": comment, "enrollment_id": enrollment_id}, headers:
    { "authorization" => @auth_token })
    response
  end
end
